# pangeo-forge-runner

[![Documentation Status](https://readthedocs.org/projects/pangeo-forge-runner/badge/?version=latest)](https://pangeo-forge-runner.readthedocs.io/en/latest/?badge=latest)
![Tests passing](https://github.com/yuvipanda/pangeo-forge-runner/actions/workflows/unit-test.yml/badge.svg)
[![codecov](https://codecov.io/gh/yuvipanda/pangeo-forge-runner/branch/main/graph/badge.svg?token=TN5SO7X9LU)](https://codecov.io/gh/yuvipanda/pangeo-forge-runner)
[![PyPI version](https://badge.fury.io/py/pangeo-forge-runner.svg)](https://badge.fury.io/py/pangeo-forge-runner)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/yuvipanda/pangeo-forge-runner/main.svg)](https://results.pre-commit.ci/latest/github/yuvipanda/pangeo-forge-runner/main)

Commandline tool to manage [pangeo-forge](https://pangeo-forge.readthedocs.io/en/latest/)
feedstocks

## Tutorials

```{toctree}
:maxdepth: 1

tutorial/flink
```

## Contents

```{toctree}
:maxdepth: 2

reference/index
```

## Development

```{toctree}
:maxdepth: 2

development/release
```
